@@ -1,5 +1,8 @@
 import importlib
 import json
+import os
+from importlib._bootstrap_external import SourceFileLoader
+from pathlib import Path
 from subprocess import Popen, PIPE
 
 import requests
@@ -17,11 +20,22 @@ from response_differ.cheks import Replayed
 #custom_serializer_path = 'tests.custom_serializer2'
 #custom_serializer_path = []
 
+
+def import_pages(path):
+    def _import():
+        name = os.path.splitext(file)[0]
+        return SourceFileLoader(name, os.path.join(root, file)).load_module()
+
+    pwd = os.path.abspath(os.curdir)
+    for root, _dirs, files in os.walk(pwd):
+        for file in files:
+            if file in path:
+                _import()
+
+
 def get_vcr():
     if Serialize.custom_serializer_path:
-        d = Serialize.custom_serializer_path[0].replace('/', '.')
-        s = d.replace('.py', '')
-        serializer = importlib.import_module(s)
+        serializer = import_pages(Serialize.custom_serializer_path[0])
     else:
         from response_differ.cassetes import serializer
 
@@ -31,6 +45,7 @@ def get_vcr():
     d_vcr.register_persister(serializer.CustomPersister)
     return d_vcr
 
+
 def get_prepared_request(data):
     prepared = requests.PreparedRequest()
     prepared.method = data["method"]
