@@ -22,10 +22,9 @@ def differ():
 
 
 #@click.pass_context
-@differ.command()
+#@differ.command()
 #@click.option("cassette_path", type=click.Path(exists=True))
 @click.argument("cassette_path", type=str)
-@click.option("--uri", help="A regexp that filters interactions by their request URI.", required=False, type=str)
 @click.option("--host", help="HOST.", required=False, type=str, default='')
 @click.option("--protocol", help="protocol", required=False, type=str)
 @click.option("--diff", '-d',  help="Comparing new response with the old", required=False, type=bool)
